import * as vue from 'vue';

/**
 *
 * @param key the key in the local storage
 * @param defaultValue default value if there is no value in the local storage. It is most recommended to provide this value
 * @param options Options for the hook. This is an object that can have the following properties:
 * - `serializer` the function to serialize the object to string before storing it in the local storage. Default to `JSON.stringify`
 * - `parser` the function to parse the string to object. Default to safeParse which will return the value itself if it cannot be parsed
 * - `logger` the function to log the error. Default to `console.error`
 */
declare function useLocalStorage<T>(key: string, defaultValue?: T): vue.Ref<string | vue.UnwrapRef<T>>;

export { useLocalStorage as default, useLocalStorage };
